-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}

local running = true
local scenario = nil
local speed = 0

local helper = require('scenariohelper')

local function reset()
    running = false
end

local function fail(reason)
    scenarios.finish({failed = reason})
    reset()
end

local function success(speed)
    local result = {msg = 'Well done, your speed: '..string.format("%0.2f", speed * 3.6)..'km/h'}
    scenarios.finish(result)
    reset()
end

local function onRaceStart()
    reset()

    helper.init()
    helper.setAiMode('aiCar1', 'manual')
    --helper.setAiAggression('aiCar1', 1.2)
    helper.setAiTarget('aiCar1', 'road2_2')
    helper.trackVehicle('aiCar1', 'aiCar')
    helper.trackVehicle('scenario_player0', 'playerCar')

    running = true
end

local function onRaceTick(raceTickTime)
    if not running then
        return
    end

    helper.update(raceTickTime)

    local aiCarData = map.objects.aiCar
    local playerCarData = map.objects.playerCar

    if not aiCarData or not playerCarData then
        return
    end

    if aiCarData.damage > 0 and speed == 0 then
        speed = playerCarData.vel:length()
    end

    if aiCarData.damage >= 5000 then
        success(speed)
    end

    if scenario.timer > 16 then
        fail("You weren't fast enough!")
    end
end

local function onScenarioChange(sc)
    scenario = sc
end

M.onRaceStart = onRaceStart
M.onRaceTick = onRaceTick
M.onScenarioChange = onScenarioChange

return M